@@ -10,14 +10,16 @@ export default (fixture, loaderOptions = {}, config = {}) => {
     context: path.resolve(__dirname, '../fixtures'),
     entry: path.resolve(__dirname, '../fixtures', fixture),
     output: {
+      publicPath: '',
       path: path.resolve(__dirname, '../outputs'),
       filename: '[name].bundle.js',
       chunkFilename: '[name].chunk.js',
+      libraryTarget: 'commonjs2',
     },
     module: {
       rules: [
         {
-          test: /\.(gif|jpg|png|svg)$/i,
+          test: /\.(gif|jpg|png|svg|html|unknown)$/i,
           rules: [
             {
               loader: path.resolve(__dirname, '../../src'),
